@@ -26,7 +26,7 @@ import gitlab
 from cliff.command import Command
 
 from fork2gitlab import git
-from fork2gitlab.utils import str2int, get_authorized_url
+from fork2gitlab.utils import get_authorized_url, str2int
 
 
 class SyncCommand(Command):
@@ -49,20 +49,37 @@ class SyncCommand(Command):
         MERGE_REQUEST = 2
 
     def take_action(self, parsed_args):
-        project_name = parsed_args.project_name
+        group_path, _, project_name = parsed_args.project_name.rpartition("/")
         target_branch = parsed_args.target_branch
         source_branch = parsed_args.source_branch
-        logging.info("project_name: %s, branch: %s", project_name, target_branch)
+        logging.info("group_path: %s, project_name: %s, branch: %s",
+                     group_path, project_name, target_branch)
+
         gl = gitlab.Gitlab.from_config()
         gl.auth()
 
-        # Find the project
-        user = gl.users.get(gl.user.id)
-        projects = user.projects.list(search=project_name)
+        # Find the group project
+        if group_path:
+            group = next(iter(
+                group
+                for group in gl.groups.list(search=group_path)
+                if group.full_path == group_path
+            ), None)
+            if not group:
+                logging.error("Unknown group path %s", group_path)
+                return
+            projects = [
+                project
+                for project in group.projects.list(search=project_name)
+                if project.path == project_name
+            ]
+        else:
+            user = gl.users.get(gl.user.id)
+            projects = user.projects.list(search=project_name)
 
         len_projects = len(projects)
         if len_projects == 0:
-            logging.error("Unknown project for user %s", user.username)
+            logging.error("Unknown project for %s", group if group else user.username)
             return
 
         interactive = not parsed_args.non_interactive
@@ -135,7 +152,10 @@ class SyncCommand(Command):
 
         parser.add_argument(
             "project_name",
-            help="Your project on gitlab. "
+            help="Project on gitlab. "
+                 "If it doesn't contain slashes (/) then it has to be your personal project."
+                 "Slashes indicate it's in a group with the first components being the group path"
+                 " and the last one the project name"
                  "Since you're using your account it has to be accessible by you."
         )
         parser.add_argument(
